{% load htmlparams %}

{% htmlparams %}
	{% htmlparam body %}
        <div class="fr-mt-3w comparison-main-values">
            <div>Dernier millésime:</div>
            <div class="territory-value fr-text--lg fr-mb-0 delay-spinner">
                <span>{% include "territories_dashboard_lib/website/pages/indicators/components/loader.html" with width=32 %}</span>
                <span class="unite">{{indicator.unite}}</span>
            </div>
            <div class="compared-territory-value fr-text--lg fr-mb-0 delay-spinner">
                <span>{% include "territories_dashboard_lib/website/pages/indicators/components/loader.html" with width=32 %}</span>
                <span class="unite">{{indicator.unite}}</span>
            </div>
        </div>
        <div style="height: 300px;">
            <canvas class="history-chart" aria-describedby="{{indicator.id}}values-export-csv"></canvas>
        </div>
        {% include "territories_dashboard_lib/website/pages/indicators/components/chart-buttons.html" with name="Historique comparaison" route="values" indicator=indicator pattern="show" tracking_objet="comparaison-historique" %}
	{% endhtmlparam %}

    {% htmlparam footer %}
        {% include "./histogram.html" %}
    {% endhtmlparam %}

    {% include "territories_dashboard_lib/website/pages/indicators/components/indicator-card.html" with indicator=indicator %}
{% endhtmlparams %}
